from taktile_auth.entities.permission import Permission, PermissionDefinition
from taktile_auth.entities.resource import Resource, ResourceDefinition
from taktile_auth.entities.role import Role, RoleDefinition
